@@ -1,7 +1,7 @@
 //
 // ned, https://github.com/nevdelap/ned, tests/files.rs
 //
-// Copyright 2016-2021 Nev Delap (nevdelap at gmail)
+// Copyright 2016-2024 Nev Delap (nevdelap at gmail)
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -202,7 +202,7 @@ fn test(args: &str, expected_file_names: &[&str]) {
         .split_whitespace()
         .map(|arg| arg.to_string())
         .collect::<Vec<String>>();
-    env::set_var("NED_DEFAULTS", "");
+    unsafe { env::set_var("NED_DEFAULTS", "") };
     let options_with_defaults = OptionsWithDefaults::new(make_opts(), &args).unwrap();
     let parameters = get_parameters(&options_with_defaults).unwrap();
     let paths = Files::new(&parameters, &parameters.globs[0]);
